%  modelit.ui.ComboBox - A component that combines a button and an editable field.   
%  A combobox can open up by pressing the button to display a list of choices which can selected with the mouse.   
%  A new choice may also be modified by typing in the textfield, as the user types the set of possible choices will narrow down   
%  When not open, a combobox indicates the current choice.   
%  Comboboxes are useful when you want to provide users with a number of mutually exclusive choices, but do not want to take up the amount of space that a series of radio buttons requires   
%  A callback is triggered after a user has changed the selected item.   
%   
%  modelit.ui.ComboBox Properties:   
%    Style                  - ComboBox (Read only)   
%    NextFocusableComponent - Specifies the next component to get the focus after this one.   
%    Callback               - Specifies the function that should be executed when the user has finished editing the combobox or when the user has selected a new item.   
%    CMenu                  - The handle of the context menu associated with the combobox.   
%    Content                - Specifies the choicelist for the combobox.   
%    ContextMenu            - The handle of the context menu associated with the combobox.   
%    Editable               - If true new items can be added by the user to the choicelist   
%    Format                 - Set the format of the combox contents.   
%    Iconset                - The name of the jar file with icons or the full path to the jar file.   
%    Prompt                 - The prompt text (input hint) for the combobox   
%    Value                  - The index in the choicelist of the current chosen option.   
%    HorizontalAlignment    - The horizontal text alignment of the combobox.   
%    String                 - The name of the current chosen option.   
%    PrototypeDisplayValue  - If a prototype display value is specified, the preferred size of   
%    TooltipString          - The TooltipString property specifies the text of the tooltip associated with the combobox. When the   
%    ForegroundColor        - The foreground (text) color of the combobox.   
%    BackgroundColor        - The background color of the combobox.   
%    MatlabHandle           - The handle of the associated Matlab container for this java object.   
%    JavaHandle             - The underlying java object.   
%    Interruptible          - Callback routine interruption.   
%    BusyAction             - Callback queuing.   
%    Position               - Size and location of the component.   
%    Tag                    - User specified object identifier.   
%    Userdata               - User specified data for this modelit.ui.Jacontrol object   
%    Units                  - Used to interpret the extent and position properties.   
%    Visible                - Component visibility.   
%    Enable                 - Disable or enable the component.   
%    Extent                 - Position rectangle (read only).   
%    Clipping               - Clipping mode.   
%    Type                   - String with the object type.   
%    FontUnits              - This property determines the units used by the FontSize property.   
%    FontWeight             - Setting this property to bold selects a bold version of the component's font, when it is available on your system.   
%    FontSize               - A number specifying the size in pixels of the component's font.   
%    FontName               - The name of the font in which to display the text in the components.   
%    FontAngle              - Setting this property to italic selects a slanted version of the component's font, when it is available on your system.   
%    MouseEnteredCallback   - Specifies the callback function that should be executed when the mouse enters the component.   
%    MouseExitedCallback    - Specifies the callback function that should be executed when the mouse exits the component.   
%    MouseClickedCallback   - Specifies the function that should be executed when the mouse is clicked on the component   
%    PreferredSize          - The component's preferred size, measured in pixels.   
%    MinimumSize            - The component's minimum size, measured in pixels.   
%    MaximumSize            - The component's maximum size, measured in pixels.   
%    Parent                 - The component's parent.   
%    Children               - The component's children.   
%   
%  modelit.ui.ComboBox Methods:   
%    cleanup                 - Reset object fields to empty values, called by the destructor.   
%    ComboBox                - modelit.ui.ComboBox constructor   
%    delete                  - modelit.ui.Jacontrol destructor.   
%    isappdata               - True if application defined data exists.   
%    getappdata              - Get application defined data.   
%    setappdata              - Set application defined data.   
%    ishandle                - Returns true if this is a valid graphics object   
%    java                    - Returns the underlying Java object   
%    handle                  - Returns the handle of the component's Matlab container   
%    ancestor                - Returns the handle of the closest ancestor of obj   
%    browse                  - (Static) Browse the available classes in the modelit.ui package   
%    getDefaultScalarElement - (Static) Create a default object for heterogeneous arrays.   
%    ne                      - Not equal relation for handles.   
%    eq                      - Equal relation for handles.   
%    findobj                 - Returns the objects whose property values match those passed as param-value pairs to the findobj command.   
%    set                     - Set object properties   
%    get                     - GET    Get MATLAB object properties.   
%    setdisp                 - SETDISP    Specialized MATLAB object property display.   
%    getdisp                 - GETDISP    Specialized MATLAB object property display.   
   
   
% © Modelit 2006-2023   
% Matlab release: 2021a   
% Date: 2023/03/30 18:46:31   
