%  modelit.ui.Table - A table with sorting and filtering support.   
%  Furthermore the table has some built in features to render icons, dates, comboboxes,   
%  Change color of foreground and background of the table cells etc.   
%   
%  modelit.ui.Table Properties:   
%    Style                  - Table (Read only)   
%    ColumnClass            - (Read only) CellString with class per column.   
%    Order                  - (Read only) Order of elements in current table   
%    NextFocusableComponent - Specifies the next component to get the focus after this one.   
%    Anchor                 - The index (row and column) of the first selected cell in the current selection.   
%    BackgroundColor        - 1-by-3 matrix of RGB values, default value is system dependent   
%    GridBackground         - 1-by-3 matrix of RGB values, default value is system dependent   
%    Border                 - Indicates if a border is shown around the table's scrollpane.   
%    Busy                   - If true a indeterminate progress indicator appears on the faded table.   
%    CellTooltips           - Set the tooltips for the table cells.   
%    CellBackgroundColor    - Specifies an index in the ColorSet for every table cell.   
%    CellForegroundColor    - Specifies an index in the ColorSet for every table cell.   
%    CellSelection          - Indicates whether the user can select single cells (true) or only rows (false) in the table.   
%    ColorSet               - First column is a key   
%    ColumnControl          - The Column Control is an icon that renders to the right of the column headers,   
%    Content                - OBSOLETE. This property has been replaced by properties 'data' and 'columnnames'   
%    ColumnEditable         - Specifies the columns which are editable.   
%    DateFormat             - OBSOLETE   
%    NumberFormat           - Specifies the numberformat for all the numeric columns in the table   
%    Editable               - Specifies the columns which are editable.   
%    ColumnFormats          - Set the format of the table's columns.   
%    ColumnNames            - Set the names (headers) of the table columns.   
%    ColumnOrder            - Set the order and visibility of the columns   
%    ColumnTooltips         - Set the tooltips for the table columns.   
%    ColumnWidths           - Set the widths of the table's columns, -1 if auto.   
%    ContextMenu            - The handle of the context menu associated with the table.   
%    CMenu                  - The handle of the context menu associated with the table.   
%    ControlButtonMenu      - The handle of the menu associated with the table's columncontrol button in the right upper corner of the table.   
%    BMenu                  - The handle of the menu associated with the table's columncontrol button in the right upper corner of the table.   
%    Data                   - Data for table, every column should have the same format e.g. all strings or numbers.   
%    DragEnabled            - Specifies if the content of the selected cells/rows/columns can be   
%    EditCallback           - Function that executes when the user changes the value of a cell in the table.   
%    DataCallback           - Function that executes when the user changes the value of a cell in the table.   
%    FilterVisible          - Show data dependent filter in the columns of the table   
%    FilteredRows           - Specifies the visible rows. If a vector of booleans is used its length must be equal to the number of rows in the table.   
%    RowFilter              - Specifies the visible rows. If a vector of booleans is used its length must be equal to the number of rows in the table.   
%    ForegroundColor        - The foreground color of the table (font color).   
%    Grid                   - Specifies whether the table draws horizontal lines, vertical lines, both or nothing between the table cells.   
%    GridColor              - The color of the table's (partial) grid when visible.   
%    HeaderBackgroundColor  - The background color of the table header.   
%    HeaderFontAngle        - Setting this property to italic selects a slanted version of the table header's font.   
%    HeaderFontName         - The name of the font in which to display the string in the table header.   
%    HeaderFontSize         - A number specifying the size in pixels of the table header's font.   
%    HeaderFontWeight       - Setting this property to bold selects a bold version of the table header's font.   
%    HeaderForegroundColor  - The foreground color of the table (text color) .   
%    HeaderVisible          - Display a header with columnnames above the table.   
%    Highlighter            - Rows can be highlighted to make it easier to distinguish between different rows by using a subtle background color scheme for every other row.   
%    Iconset                - The name of the jar file with icons or the full path to the jar file.   
%    InfoLabel              - Specifies if a label with info is visible in the lower right   
%    InfoLabelFontAngle     - Setting this property to italic selects a slanted version of the info label's font, when it is available on your system.   
%    InfoLabelFontName      - The name of the font in which to display the string in the info label.   
%    InfoLabelFontSize      - A number specifying the size in pixels of the info label's font.   
%    InfoLabelFontWeight    - Setting this property to bold selects a bold version of the infor label's font, when it is available on your system.   
%    KeyPressedCallback     - Function that executes when the user presses a key or combination of keys.   
%    PasteEnabled           - Allow pasting of cells (from Excel) into table   
%    Prompt                 - The prompt text (shown if table is empty)   
%    Scrollbar              - Normally a Table in a scrollPane will fit all columns within the scrollpane's viewport,   
%    SelectedColumns        - A vector of indices corresponding to the currently selected table columns.   
%    SelectedRows           - A a vector of indices corresponding to the currently selected table rows.   
%    Sortable               - Indicates whether the table is sorttable   
%    Value                  - A a vector of indices corresponding to the currently selected table rows.   
%    Rows                   - A a vector of indices corresponding to the currently selected table rows.   
%    SelectionCallback      - Function that executes when the user changes the current selection.   
%    Callback               - Function that executes when the user changes the current selection.   
%    SelectionMode          - The selection mode. The following selectionMode values are allowed:   
%    Sortorder              - Specifies the sortorder per column:   
%    TableFilterHeader      - Specifies if the tableheader for filtering is visible   
%    RowHeight              - The height in pixels of each row in the table.   
%    TooltipString          - The TooltipString property specifies the text of the tooltip associated with the table.   
%    MatlabHandle           - The handle of the associated Matlab container for this java object.   
%    JavaHandle             - The underlying java object.   
%    Interruptible          - Callback routine interruption.   
%    BusyAction             - Callback queuing.   
%    Position               - Size and location of the component.   
%    Tag                    - User specified object identifier.   
%    Userdata               - User specified data for this modelit.ui.Jacontrol object   
%    Units                  - Used to interpret the extent and position properties.   
%    Visible                - Component visibility.   
%    Enable                 - Disable or enable the component.   
%    Extent                 - Position rectangle (read only).   
%    Clipping               - Clipping mode.   
%    Type                   - String with the object type.   
%    FontUnits              - This property determines the units used by the FontSize property.   
%    FontWeight             - Setting this property to bold selects a bold version of the component's font, when it is available on your system.   
%    FontSize               - A number specifying the size in pixels of the component's font.   
%    FontName               - The name of the font in which to display the text in the components.   
%    FontAngle              - Setting this property to italic selects a slanted version of the component's font, when it is available on your system.   
%    MouseEnteredCallback   - Specifies the callback function that should be executed when the mouse enters the component.   
%    MouseExitedCallback    - Specifies the callback function that should be executed when the mouse exits the component.   
%    MouseClickedCallback   - Specifies the function that should be executed when the mouse is clicked on the component   
%    PreferredSize          - The component's preferred size, measured in pixels.   
%    MinimumSize            - The component's minimum size, measured in pixels.   
%    MaximumSize            - The component's maximum size, measured in pixels.   
%    Parent                 - The component's parent.   
%    Children               - The component's children.   
%   
%  modelit.ui.Table Methods:   
%    cleanup                 - Reset object fields to empty values, called by the destructor.   
%    Table                   - modelit.ui.Table constructor.   
%    tableAction             - Programmatically select a row in the table.   
%    setValueAt              - Programmatically set a value in the table.   
%    getValueAt              - Get a value in the table.   
%    delete                  - modelit.ui.Jacontrol destructor.   
%    isappdata               - True if application defined data exists.   
%    getappdata              - Get application defined data.   
%    setappdata              - Set application defined data.   
%    ishandle                - Returns true if this is a valid graphics object   
%    java                    - Returns the underlying Java object   
%    handle                  - Returns the handle of the component's Matlab container   
%    ancestor                - Returns the handle of the closest ancestor of obj   
%    browse                  - (Static) Browse the available classes in the modelit.ui package   
%    getDefaultScalarElement - (Static) Create a default object for heterogeneous arrays.   
%    ne                      - Not equal relation for handles.   
%    eq                      - Equal relation for handles.   
%    findobj                 - Returns the objects whose property values match those passed as param-value pairs to the findobj command.   
%    set                     - Set object properties   
%    get                     - GET    Get MATLAB object properties.   
%    setdisp                 - SETDISP    Specialized MATLAB object property display.   
%    getdisp                 - GETDISP    Specialized MATLAB object property display.   
   
   
% © Modelit 2006-2023   
% Matlab release: 2021a   
% Date: 2023/03/30 18:46:31   
